/*
* kboxctl.c
* interface for Kreatel's kboxdrv interface
*/

#include <sys/ioctl.h>
#include <sys/stat.h>
#include <string.h>
#include <errno.h>
#include <unistd.h>
#include <fcntl.h>

#include <linux/kbox.h>

#ifndef VERSION
#  define VERSION "0.0.1"
#endif

/* KBOX_DEVICE_NAME is defined in linux/kbox.h */
#define KBOXDEVPATH ("/dev/" KBOX_DEVICE_NAME)

void usage_and_quit()
{
	printf(	"Options for this program:\n\n"
		"kboxctl <command> [command parameters]\n\n"
		"Available commands:\n"
		"-------------------\n"
		"led_get\n"
		"        This will print a numerical value indicating LED status.\n"
		"        For the VIP1710, the values are\n"
		"        green: %d\n"
		"        red: %d\n"
		"        orange: %d (does not work on my VIP1710)\n"
		"        off: %d\n"
		"led_set <nr>\n"
		"        This will set the LED status. Use values as indicated above\n"
		"        for led_get.\n"
		"\nkboxctl was initially written by Hans-Werner Hilse <hilse@web.de>\n"
		"No warranties of any sort are given. This software may potentially\n"
		"destroy your hardware (though it didn't for the author and he did\n"
		"not create it for such purposes).\n"
		"License: Copy and modify this software in source and binary versions as you want.\n",
		KBOX_LED_GREEN, KBOX_LED_RED, KBOX_LED_ORANGE, KBOX_LED_OFF);
	
	exit(1);
}

int openkdev()
{
	return open(KBOXDEVPATH, O_RDWR); 
}

static int led_get()
{
	int fd, ledstate, ret;
	fd = openkdev();
	if(fd == -1)
		goto error;
	ret = ioctl(fd, KBOX_IOCTL_LED_GET, &ledstate); 
	close(fd);
	if (ret == -1)
		goto error;
	printf("%d\n", ledstate);
	exit(0);
error:
	perror();
	exit(1);
}

static int led_set(int ledstate)
{
	int fd, ret;

	if(ledstate < 0 || ledstate > KBOX_LED_ORANGE)
		usage_and_quit();

	fd = openkdev();
	if(fd == -1)
		goto error;
	ret = ioctl(fd, KBOX_IOCTL_LED_SET, &ledstate); 
	close(fd);
	if (ret == -1)
		goto error;
	exit(0);
error:
	perror();
	exit(1);
}

int main(int argc, char *argv[])
{
	if(argc < 2)
		usage_and_quit();
	if(!strcmp(argv[1], "led_get")) {
		led_get();
	} else if(!strcmp(argv[1], "led_set")) {
		if(argc != 3)
			usage_and_quit();
		led_set(atoi(argv[2]));
	} else {
		usage_and_quit();
	}
}
